use chrono::NaiveDate;
use serde::Serialize;
use sqlx::SqlitePool;

use self::{
    planned_event::{PlannedEvent, PlannedEventWithUser},
    trip::{Trip, TripWithUser},
};

pub mod log;
pub mod planned_event;
pub mod trip;
pub mod tripdetails;
pub mod user;
pub mod usertrip;
//pub mod users;

#[derive(Serialize)]
pub struct Day {
    day: NaiveDate,
    planned_events: Vec<PlannedEventWithUser>,
    trips: Vec<TripWithUser>,
}

impl Day {
    pub async fn new(db: &SqlitePool, day: NaiveDate) -> Self {
        Self {
            day,
            planned_events: PlannedEvent::get_for_day(db, day).await,
            trips: Trip::get_for_day(db, day).await,
        }
    }
}
